@@ -4,24 +4,18 @@ templates = (
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterISS3IUL3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned long,3 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
-  ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterISS2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
-  ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterISS3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterISS2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterISS3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUC2IUL2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned long,2 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUC3IUL3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned long,3 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUC2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUC3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
-  ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
-  ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUC2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUC3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUS2IUL2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned long,2 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUS3IUL3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned long,3 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUS2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUS3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
-  ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUS2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
-  ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUS3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
   ('ConnectedComponentImageFilter', 'itk::ConnectedComponentImageFilter', 'itkConnectedComponentImageFilterIVF22ISS2', True, 'itk::Image< itk::Vector< float,2 >,2 >, itk::Image< signed short,2 >'),
@@ -64,24 +58,18 @@ templates = (
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterISS3IUL3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned long,3 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
-  ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterISS2IUC2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned char,2 >'),
-  ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterISS3IUC3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned char,3 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterISS2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterISS3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUC2IUL2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned long,2 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUC3IUL3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned long,3 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUC2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUC3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
-  ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
-  ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUC2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUC3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUS2IUL2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned long,2 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUS3IUL3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned long,3 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUS2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUS3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
-  ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUS2IUC2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned char,2 >'),
-  ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUS3IUC3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned char,3 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
   ('HardConnectedComponentImageFilter', 'itk::HardConnectedComponentImageFilter', 'itkHardConnectedComponentImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
   ('RelabelComponentImageFilter', 'itk::RelabelComponentImageFilter', 'itkRelabelComponentImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
@@ -96,10 +84,22 @@ templates = (
   ('RelabelComponentImageFilter', 'itk::RelabelComponentImageFilter', 'itkRelabelComponentImageFilterIULL3IUC3', True, 'itk::Image< unsigned long long,3 >, itk::Image< unsigned char,3 >'),
   ('RelabelComponentImageFilter', 'itk::RelabelComponentImageFilter', 'itkRelabelComponentImageFilterIULL2IUS2', True, 'itk::Image< unsigned long long,2 >, itk::Image< unsigned short,2 >'),
   ('RelabelComponentImageFilter', 'itk::RelabelComponentImageFilter', 'itkRelabelComponentImageFilterIULL3IUS3', True, 'itk::Image< unsigned long long,3 >, itk::Image< unsigned short,3 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterISS2IUL2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned long,2 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterISS3IUL3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned long,3 >'),
   ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterISS2ISS2', True, 'itk::Image< signed short,2 >, itk::Image< signed short,2 >'),
   ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterISS3ISS3', True, 'itk::Image< signed short,3 >, itk::Image< signed short,3 >'),
-  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUC2IUC2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned char,2 >'),
-  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUC3IUC3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned char,3 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterISS2IUS2', True, 'itk::Image< signed short,2 >, itk::Image< unsigned short,2 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterISS3IUS3', True, 'itk::Image< signed short,3 >, itk::Image< unsigned short,3 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUC2IUL2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned long,2 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUC3IUL3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned long,3 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUC2ISS2', True, 'itk::Image< unsigned char,2 >, itk::Image< signed short,2 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUC3ISS3', True, 'itk::Image< unsigned char,3 >, itk::Image< signed short,3 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUC2IUS2', True, 'itk::Image< unsigned char,2 >, itk::Image< unsigned short,2 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUC3IUS3', True, 'itk::Image< unsigned char,3 >, itk::Image< unsigned short,3 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUS2IUL2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned long,2 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUS3IUL3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned long,3 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUS2ISS2', True, 'itk::Image< unsigned short,2 >, itk::Image< signed short,2 >'),
+  ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUS3ISS3', True, 'itk::Image< unsigned short,3 >, itk::Image< signed short,3 >'),
   ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUS2IUS2', True, 'itk::Image< unsigned short,2 >, itk::Image< unsigned short,2 >'),
   ('ScalarConnectedComponentImageFilter', 'itk::ScalarConnectedComponentImageFilter', 'itkScalarConnectedComponentImageFilterIUS3IUS3', True, 'itk::Image< unsigned short,3 >, itk::Image< unsigned short,3 >'),
   ('ThresholdMaximumConnectedComponentsImageFilter', 'itk::ThresholdMaximumConnectedComponentsImageFilter', 'itkThresholdMaximumConnectedComponentsImageFilterISS2', True, 'itk::Image< signed short,2 >'),
@@ -145,4 +145,4 @@ templates = (
   ('VectorConnectedComponentImageFilter', 'itk::VectorConnectedComponentImageFilter', 'itkVectorConnectedComponentImageFilterICVF42IUS2', True, 'itk::Image< itk::CovariantVector< float,4 >,2 >, itk::Image< unsigned short,2 >'),
   ('VectorConnectedComponentImageFilter', 'itk::VectorConnectedComponentImageFilter', 'itkVectorConnectedComponentImageFilterICVF43IUS3', True, 'itk::Image< itk::CovariantVector< float,4 >,3 >, itk::Image< unsigned short,3 >'),
 )
-snake_case_functions = ('relabel_component_image_filter', 'vector_connected_component_image_filter', 'threshold_maximum_connected_components_image_filter', 'connected_component_image_filter', 'scalar_connected_component_image_filter', 'hard_connected_component_image_filter', 'connected_component_functor_image_filter', )
+snake_case_functions = ('vector_connected_component_image_filter', 'relabel_component_image_filter', 'connected_component_functor_image_filter', 'connected_component_image_filter', 'hard_connected_component_image_filter', 'scalar_connected_component_image_filter', 'threshold_maximum_connected_components_image_filter', )
