@@ -230,4 +230,4 @@ templates = (
   ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMF3IF3', True, 'itk::Mesh< float,3 >, itk::Image< float,3 > '),
   ('TriangleMeshToBinaryImageFilter', 'itk::TriangleMeshToBinaryImageFilter', 'itkTriangleMeshToBinaryImageFilterMD3ID3', True, 'itk::Mesh< double,3 >, itk::Image< double,3 > '),
 )
-snake_case_functions = ('connected_regions_mesh_filter', 'transform_mesh_filter', 'mesh_source', 'mesh_to_mesh_filter', 'binary_mask3_d_mesh_source', 'vtk_poly_data_reader', 'image_to_mesh_filter', 'triangle_mesh_to_binary_image_filter', )
+snake_case_functions = ('mesh_source', 'vtk_poly_data_reader', 'triangle_mesh_to_binary_image_filter', 'image_to_mesh_filter', 'binary_mask3_d_mesh_source', 'transform_mesh_filter', 'mesh_to_mesh_filter', 'connected_regions_mesh_filter', )
