@@ -125,4 +125,4 @@ templates = (
   ('SymmetricForcesDemonsRegistrationFilter', 'itk::SymmetricForcesDemonsRegistrationFilter', 'itkSymmetricForcesDemonsRegistrationFilterID2ID2IVF42', True, 'itk::Image< double,2 >, itk::Image< double,2 >, itk::Image< itk::Vector< float,4 >,2 >'),
   ('SymmetricForcesDemonsRegistrationFilter', 'itk::SymmetricForcesDemonsRegistrationFilter', 'itkSymmetricForcesDemonsRegistrationFilterID3ID3IVF43', True, 'itk::Image< double,3 >, itk::Image< double,3 >, itk::Image< itk::Vector< float,4 >,3 >'),
 )
-snake_case_functions = ('demons_registration_filter', 'multi_resolution_pde_deformable_registration', 'pde_deformable_registration_filter', 'level_set_motion_registration_filter', 'symmetric_forces_demons_registration_filter', )
+snake_case_functions = ('multi_resolution_pde_deformable_registration', 'demons_registration_filter', 'level_set_motion_registration_filter', 'pde_deformable_registration_filter', 'symmetric_forces_demons_registration_filter', )
