@@ -2,8 +2,7 @@ depends = ('ITKPyBase', 'ITKStatistics', 'ITKSpatialObjects', 'ITKSmoothing', 'I
 templates = (
   ('BlockMatchingImageFilter', 'itk::BlockMatchingImageFilter', 'itkBlockMatchingImageFilterIF3', True, 'itk::Image< float,3 >'),
   ('BlockMatchingImageFilter', 'itk::BlockMatchingImageFilter', 'itkBlockMatchingImageFilterID3', True, 'itk::Image< double,3 >'),
-  ('PointSet', 'itk::PointSet', 'itkPointSetVF33DTVF333FFVF3', False, 'itk::Vector< float, 3 >, 3, itk::DefaultStaticMeshTraits< itk::Vector< float, 3 >, 3, 3, float, float, itk::Vector< float, 3 > >'),
-  ('PointSet', 'itk::PointSet', 'itkPointSetD3DTD33FFD', False, 'double, 3, itk::DefaultStaticMeshTraits< double, 3, 3, float, float, double >'),
+  ('PointSet', 'itk::PointSet', 'itkPointSetVF33', False, 'itk::Vector< float, 3 >, 3'),
   ('CenteredTransformInitializer', 'itk::CenteredTransformInitializer', 'itkCenteredTransformInitializerVR3DTDISS3ISS3', True, 'itk::VersorRigid3DTransform< double >,itk::Image< signed short,3 >,itk::Image< signed short,3 >'),
   ('CenteredTransformInitializer', 'itk::CenteredTransformInitializer', 'itkCenteredTransformInitializerVR3DTDIUC3IUC3', True, 'itk::VersorRigid3DTransform< double >,itk::Image< unsigned char,3 >,itk::Image< unsigned char,3 >'),
   ('CenteredTransformInitializer', 'itk::CenteredTransformInitializer', 'itkCenteredTransformInitializerVR3DTDIUS3IUS3', True, 'itk::VersorRigid3DTransform< double >,itk::Image< unsigned short,3 >,itk::Image< unsigned short,3 >'),
@@ -158,4 +157,4 @@ templates = (
   ('TransformParametersAdaptorBase', 'itk::TransformParametersAdaptorBase', 'itkTransformParametersAdaptorBaseF3', True, 'itk::Transform< float,3,3 >'),
   ('TransformParametersAdaptorBase', 'itk::TransformParametersAdaptorBase', 'itkTransformParametersAdaptorBaseD3', True, 'itk::Transform< double,3,3 >'),
 )
-snake_case_functions = ('mesh_source', 'block_matching_image_filter', 'mesh_to_mesh_filter', 'multi_resolution_pyramid_image_filter', 'multi_resolution_image_registration_method', 'recursive_multi_resolution_pyramid_image_filter', 'image_registration_method', )
+snake_case_functions = ('mesh_source', 'recursive_multi_resolution_pyramid_image_filter', 'mesh_to_mesh_filter', 'block_matching_image_filter', 'multi_resolution_image_registration_method', 'multi_resolution_pyramid_image_filter', 'image_registration_method', )
